@@ -321,6 +321,13 @@ static int open_tcp(const struct options *const o, int mode)
     exit(2);
   }
 
+  {
+    int i = 1;
+    if (setsockopt(fd, SOL_SOCKET, SO_REUSEADDR, &i, sizeof(i)) == -1) {
+      perror("setsockopt(REUSEADDR), [continuing]");
+    }
+  }
+
 #ifdef DO_BIND
   bzero(&serv_addr, sizeof(serv_addr));
   serv_addr.sin_family = AF_INET;
@@ -838,7 +845,7 @@ static void loop(struct options *const o, struct progstate *const state)
 		 * read position */
   char *curbuf2; /* Iterate over buf when writing */
   int nbytes = 0; /* Just one system call read() */
-  int bytes_read = 0; /* Overall, both loops */
+  long long bytes_read = 0; /* Overall, both loops */
   int pipefd[2];
 
   state->pid = getpid();
